Acknowledgments
===============

- Inspired by Sean Lim's PIC code in JAX:
  https://github.com/SeanLim2101/PiC-Code-Jax

- We acknowledge the help of the entire UWPlasma group:
  https://rogerio.physics.wisc.edu/
